@@ -28,7 +28,7 @@ extern "C" {
  * has been modified, and reset anytime the major API version has
  * been changed. Used to keep track if a field has been added or not.
  */
-#define SVT_AV1_ENC_ABI_VERSION 6
+#define SVT_AV1_ENC_ABI_VERSION 0
 
 //***HME***
 
@@ -43,7 +43,6 @@ extern "C" {
 #endif
 #endif /* ATTRIBUTE_PACKED */
 typedef enum ATTRIBUTE_PACKED {
-    ENC_MRS        = -2, // Highest quality research mode (slowest)
     ENC_MR         = -1, //Research mode with higher quality than M0
     ENC_M0         = 0,
     ENC_M1         = 1,
@@ -65,8 +64,7 @@ typedef enum ATTRIBUTE_PACKED {
 #define DEFAULT -1
 
 #define EB_BUFFERFLAG_EOS 0x00000001 // signals the last packet of the stream
-#define EB_BUFFERFLAG_SHOW_EXT \
-    0x00000002 // signals that the packet contains a show existing frame at the end
+#define EB_BUFFERFLAG_SHOW_EXT 0x00000002 // signals that the packet contains a show existing frame at the end
 #define EB_BUFFERFLAG_HAS_TD 0x00000004 // signals that the packet contains a TD
 #define EB_BUFFERFLAG_IS_ALT_REF 0x00000008 // signals that the packet contains an ALT_REF frame
 #define EB_BUFFERFLAG_ERROR_MASK \
@@ -113,8 +111,6 @@ struct EbSvtAv1MasteringDisplayInfo {
 typedef struct PredictionStructureConfigEntry {
     uint32_t temporal_layer_index;
     uint32_t decode_order;
-    int32_t  ref_list0[REF_LIST_MAX_DEPTH];
-    int32_t  ref_list1[REF_LIST_MAX_DEPTH];
 } PredictionStructureConfigEntry;
 
 // super-res modes
@@ -178,7 +174,7 @@ typedef enum EbSFrameMode {
 } EbSFrameMode;
 
 /* Indicates what prediction structure to use
- * was PredStructure in EbDefinitions.h
+ * was PredStructure in definitions.h
  * Only SVT_AV1_PRED_LOW_DELAY_B and SVT_AV1_PRED_RANDOM_ACCESS are valid
  */
 typedef enum SvtAv1PredStructure {
@@ -198,6 +194,24 @@ typedef enum SvtAv1RcMode {
     SVT_AV1_RC_MODE_CBR        = 2, // constant bit rate
 } SvtAv1RcMode;
 
+typedef enum SvtAv1FrameUpdateType {
+    SVT_AV1_KF_UPDATE,
+    SVT_AV1_LF_UPDATE,
+    SVT_AV1_GF_UPDATE,
+    SVT_AV1_ARF_UPDATE,
+    SVT_AV1_OVERLAY_UPDATE,
+    SVT_AV1_INTNL_OVERLAY_UPDATE, // Internal Overlay Frame
+    SVT_AV1_INTNL_ARF_UPDATE, // Internal Altref Frame
+    SVT_AV1_FRAME_UPDATE_TYPES
+} SvtAv1FrameUpdateType;
+
+typedef struct SvtAv1FrameScaleEvts {
+    uint32_t  evt_num;
+    uint64_t *start_frame_nums;
+    uint32_t *resize_kf_denoms;
+    uint32_t *resize_denoms;
+} SvtAv1FrameScaleEvts;
+
 // Will contain the EbEncApi which will live in the EncHandle class
 // Only modifiable during config-time.
 typedef struct EbSvtAv1EncConfiguration {
@@ -317,17 +331,12 @@ typedef struct EbSvtAv1EncConfiguration {
      */
     EbColorFormat encoder_color_format;
 
-#if !SVT_AV1_CHECK_VERSION(1, 5, 0)
-    /* DEPRECATED: to be removed in 1.5.0. */
-    uint32_t compressed_ten_bit_format;
-#endif
-
     /**
-     * @brief Enable writing of HDR metadata in the bitstream
+     * @brief Currently unused.
      *
-     * Default is false.
+     * Default is 0.
      */
-    Bool high_dynamic_range_input;
+    uint8_t high_dynamic_range_input;
 
     /**
      * @brief Bitstream profile to use.
@@ -426,7 +435,7 @@ typedef struct EbSvtAv1EncConfiguration {
     /* Target bitrate in bits/second, only applicable when rate control mode is
      * set to 1 (VBR) or 2 (CBR).
      *
-     * Default is 2000000. */
+     * Default is 2000513. */
     uint32_t target_bit_rate;
     /* maximum bitrate in bits/second, only apllicable when rate control mode is
      * set to 0.
@@ -445,13 +454,14 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 63. */
     uint32_t max_qp_allowed;
     /* Minimum QP value allowed for rate control use, only applicable when rate
-     * control mode is set to 1. It has to be smaller or equal to maxQpAllowed.
+     * control mode is set to 1 or 2. It has to be smaller or equal to maxQpAllowed.
      *
-     * Default is 0. */
+     * Default is 4. */
     uint32_t min_qp_allowed;
 
     // DATARATE CONTROL OPTIONS
-
+#if !SVT_AV1_CHECK_VERSION(2, 0, 0)
+    /* DEPRECATED: to be removed in 2.0.0. */
     /**
      * @brief Variable Bit Rate Bias Percentage
      *
@@ -464,6 +474,7 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 100
      */
     uint32_t vbr_bias_pct;
+#endif
 
     /**
      * @brief Variable Bit Rate Minimum Section Percentage
@@ -499,7 +510,7 @@ typedef struct EbSvtAv1EncConfiguration {
      *
      * Min is 0.
      * Max is 100.
-     * Default is 25.
+     * Default is 25 for CBR and 50 for VBR.
      */
     uint32_t under_shoot_pct;
 
@@ -620,7 +631,8 @@ typedef struct EbSvtAv1EncConfiguration {
     *
     * 0 is no denoising
     * 1 is full denoising
-    */
+    *
+    * Default is 0. */
     uint8_t film_grain_denoise_apply;
 
     /* CDEF Level
@@ -635,6 +647,7 @@ typedef struct EbSvtAv1EncConfiguration {
     *
     * Default is -1. */
     int enable_restoration_filtering;
+
     /* motion field motion vector
     *
     *  Default is -1. */
@@ -702,7 +715,7 @@ typedef struct EbSvtAv1EncConfiguration {
 
     Bool enable_overlays;
     /**
-     * @brief Tune for a particular metric; 0: VQ, 1: PSNR
+     * @brief Tune for a particular metric; 0: VQ, 1: PSNR, 2: SSIM.
      *
      * Default is 1.
      */
@@ -727,11 +740,11 @@ typedef struct EbSvtAv1EncConfiguration {
     int32_t manual_pred_struct_entry_num;
 #endif
     /* Decoder-speed-targeted encoder optimization level (produce bitstreams that can be decoded faster).
-    * 0: No decoder speed optimization
-    * 1: Decoder speed optimization enabled (fast decode)
+    * 0: No decoder-targeted speed optimization
+    * 1: Level 1 of decoder-targeted speed optimizations (faster decoder-speed than level 0)
+    * 2: Level 2 of decoder-targeted speed optimizations (faster decoder-speed than level 1)
     */
-    Bool fast_decode;
-
+    uint8_t fast_decode;
     /* S-Frame interval (frames)
     * 0: S-Frame off
     * >0: S-Frame on and indicates the number of frames after which a frame may be coded as an S-Frame
@@ -768,6 +781,31 @@ typedef struct EbSvtAv1EncConfiguration {
 
     // Threads management
 
+#if CLN_LP_LVLS
+#if !SVT_AV1_CHECK_VERSION(3, 0, 0)
+    /* logical_processors refers to how much parallelization the encoder will perform
+     * by setting the number of threads and pictures that can be handled simultaneously. If
+     * the value is 0, a deafult level will be chosen based on the number of cores on the
+     * machine. Levels 1-6 are supported. Beyond that, higher inputs
+     * will map to the highest level.
+     */
+    uint32_t logical_processors;
+#endif
+
+    /* The level of parallelism refers to how much parallelization the encoder will perform
+     * by setting the number of threads and pictures that can be handled simultaneously. If
+     * the value is 0, a deafult level will be chosen based on the number of cores on the
+     * machine. Levels 1-6 are supported. Beyond that, higher inputs
+     * will map to the highest level.
+     */
+    uint32_t level_of_parallelism;
+
+    /* Pin the execution of threads to the first N logical processors.
+     * 0: unpinned
+     * N: Pin threads to socket's first N processors
+     * default 0 */
+    uint32_t pin_threads;
+#else
     /* The number of logical processor which encoder threads run on. If
      * LogicalProcessors and TargetSocket are not set, threads are managed by
      * OS thread scheduler. */
@@ -780,6 +818,7 @@ typedef struct EbSvtAv1EncConfiguration {
     * 0: unpinned
     * default 0 */
     uint32_t pin_threads;
+#endif
 
     /* Target socket to run on. For dual socket systems, this can specify which
      * socket the encoder runs on.
@@ -873,6 +912,81 @@ typedef struct EbSvtAv1EncConfiguration {
      * Default is 0.
      */
     Bool gop_constraint_rc;
+
+    /**
+     * @brief scale factors for lambda value for different frame update types
+     * factor >> 7 (/ 128) is the actual value in float
+     */
+    int32_t lambda_scale_factors[SVT_AV1_FRAME_UPDATE_TYPES];
+
+    /* Dynamic gop
+    *
+    * 0 = disable Dynamic GoP
+    * 1 = enable Dynamic GoP
+    *  Default is 1. */
+    Bool enable_dg;
+
+    /**
+     * @brief startup_mg_size
+     *
+     * When enabled, a MG with specified size will be inserted after the key frame.
+     * The MG size is determined by 2^startup_mg_size.
+     *
+     * 0: off
+     * 2: set hierarchical levels to 2 (MG size 4)
+     * 3: set hierarchical levels to 3 (MG size 8)
+     * 4: set hierarchical levels to 4 (MG size 16)
+     * Default is 0.
+     */
+    uint8_t startup_mg_size;
+
+    /* @brief reference scaling events for random access mode (resize-mode = 4)
+     *
+     * evt_num:          total count of events
+     * start_frame_nums: array of scaling start frame numbers
+     * resize_kf_denoms: array of scaling denominators of key-frame
+     * resize_denoms:    array of scaling denominators of non-key-frame
+     */
+    SvtAv1FrameScaleEvts frame_scale_evts;
+
+    /* ROI map
+    *
+    * 0 = disable ROI
+    * 1 = enable ROI
+    *  Default is 0. */
+    Bool enable_roi_map;
+
+    /* Stores the optional film grain synthesis info */
+    AomFilmGrain *fgs_table;
+
+    /* New parameters can go in under this line. Also deduct the size of the parameter */
+    /* from the padding array */
+
+    /* Variance boost
+     * false = disable variance boost
+     * true = enable variance boost
+     * Default is false. */
+    Bool enable_variance_boost;
+
+    /* @brief Selects the curve strength to boost low variance regions according to a fast-growing formula
+     * Default is 2 */
+    uint8_t variance_boost_strength;
+
+    /* @brief Picks a set of eight 8x8 variance values per superblock to determine boost
+     * Lower values enable detecting more blocks that need boosting, at the expense of more possible false positives (overall bitrate increase)
+     *  1: 1st octile
+     *  4: 4th octile
+     *  8: 8th octile
+     *  Default is 6 */
+    uint8_t variance_octile;
+
+    /*Add 128 Byte Padding to Struct to avoid changing the size of the public configuration struct*/
+#if CLN_LP_LVLS
+    uint8_t padding[128 - sizeof(Bool) - 2 * sizeof(uint8_t) - sizeof(uint32_t)];
+#else
+    uint8_t padding[128 - sizeof(Bool) - 2 * sizeof(uint8_t)];
+#endif
+
 } EbSvtAv1EncConfiguration;
 
 /**
@@ -897,8 +1011,7 @@ EB_API void svt_av1_print_version(void);
      *                  loaded with default params from the library. */
 EB_API EbErrorType svt_av1_enc_init_handle(
     EbComponentType **p_handle, void *p_app_data,
-    EbSvtAv1EncConfiguration
-        *config_ptr); // config_ptr will be loaded with default params from the library
+    EbSvtAv1EncConfiguration *config_ptr); // config_ptr will be loaded with default params from the library
 
 /* STEP 2: Set all configuration parameters.
      *
@@ -907,8 +1020,8 @@ EB_API EbErrorType svt_av1_enc_init_handle(
      * @ *pComponentParameterStructure  Encoder and buffer configurations will be copied to the library. */
 EB_API EbErrorType svt_av1_enc_set_parameter(
     EbComponentType *svt_enc_component,
-    EbSvtAv1EncConfiguration *
-        pComponentParameterStructure); // pComponentParameterStructure contents will be copied to the library
+    EbSvtAv1EncConfiguration
+        *pComponentParameterStructure); // pComponentParameterStructure contents will be copied to the library
 
 /* OPTIONAL: Set a single configuration parameter.
      *
@@ -916,8 +1029,8 @@ EB_API EbErrorType svt_av1_enc_set_parameter(
      * @ *pComponentParameterStructure  Encoder parameters structure.
      * @ *name                          Null terminated string containing the parameter name
      * @ *value                         Null terminated string containing the parameter value */
-EB_API EbErrorType svt_av1_enc_parse_parameter(
-    EbSvtAv1EncConfiguration *pComponentParameterStructure, const char *name, const char *value);
+EB_API EbErrorType svt_av1_enc_parse_parameter(EbSvtAv1EncConfiguration *pComponentParameterStructure, const char *name,
+                                               const char *value);
 
 /* STEP 3: Initialize encoder and allocates memory to necessary buffers.
      *
@@ -944,17 +1057,20 @@ EB_API EbErrorType svt_av1_enc_stream_header_release(EbBufferHeaderType *stream_
      * Parameter:
      * @ *svt_enc_component  Encoder handler.
      * @ *p_buffer           Header pointer, picture buffer. */
-EB_API EbErrorType svt_av1_enc_send_picture(EbComponentType    *svt_enc_component,
-                                            EbBufferHeaderType *p_buffer);
+EB_API EbErrorType svt_av1_enc_send_picture(EbComponentType *svt_enc_component, EbBufferHeaderType *p_buffer);
 
-/* STEP 5: Receive packet.
-     * Parameter:
-    * @ *svt_enc_component  Encoder handler.
-     * @ **p_buffer          Header pointer to return packet with.
-     * @ pic_send_done       Flag to signal that all input pictures have been sent, this call becomes locking one this signal is 1.
-     * Non-locking call, returns EB_ErrorMax for an encode error, EB_NoErrorEmptyQueue when the library does not have any available packets.*/
-EB_API EbErrorType svt_av1_enc_get_packet(EbComponentType     *svt_enc_component,
-                                          EbBufferHeaderType **p_buffer, uint8_t pic_send_done);
+/**
+ * @brief Step 5: Receive packet.
+ * This function will become blocking if either pic_send_done is set to 1 or if we are in low-delay (pred-struct=1).
+ * Otherwise, this function is non-blocking and will return EB_NoErrorEmptyQueue if there are no packets available.
+ *
+ * @param svt_enc_component The encoder handler
+ * @param p_buffer Header pointer to return packet with
+ * @param pic_send_done Flag to signal that all input pictures have been sent. Should be either 0 or 1.
+ * @return EB_API Either EB_ErrorMax for an encode error or EB_NoErrorEmptyQueue if there are no available packets.
+ */
+EB_API EbErrorType svt_av1_enc_get_packet(EbComponentType *svt_enc_component, EbBufferHeaderType **p_buffer,
+                                          uint8_t pic_send_done);
 
 /* STEP 5-1: Release output buffer back into the pool.
      *
@@ -967,8 +1083,7 @@ EB_API void svt_av1_enc_release_out_buffer(EbBufferHeaderType **p_buffer);
      * Parameter:
      * @ *svt_enc_component  Encoder handler.
      * @ *p_buffer           Output buffer. */
-EB_API EbErrorType svt_av1_get_recon(EbComponentType    *svt_enc_component,
-                                     EbBufferHeaderType *p_buffer);
+EB_API EbErrorType svt_av1_get_recon(EbComponentType *svt_enc_component, EbBufferHeaderType *p_buffer);
 
 /* OPTIONAL: get stream information
      *
@@ -976,8 +1091,7 @@ EB_API EbErrorType svt_av1_get_recon(EbComponentType    *svt_enc_component,
      * @ *svt_enc_component  Encoder handler.
      * @ *stream_info_id SVT_AV1_STREAM_INFO_ID.
      * @ *info         output, the type depends on id */
-EB_API EbErrorType svt_av1_enc_get_stream_info(EbComponentType *svt_enc_component,
-                                               uint32_t stream_info_id, void *info);
+EB_API EbErrorType svt_av1_enc_get_stream_info(EbComponentType *svt_enc_component, uint32_t stream_info_id, void *info);
 
 /* STEP 6: Deinitialize encoder library.
      *
